![beastiary logo](https://beastiary.wytamma.com/images/logo.png)

[![PyPi](https://img.shields.io/pypi/v/beastiary.svg)](https://pypi.org/project/beastiary/)
[![tests](https://github.com/Wytamma/beastiary/actions/workflows/test.yml/badge.svg)](https://github.com/Wytamma/beastiary/actions/workflows/test.yml)
[![cov](https://codecov.io/gh/Wytamma/beastiary/branch/master/graph/badge.svg)](https://codecov.io/gh/Wytamma/beastiary)
[![docs](https://github.com/Wytamma/beastiary/actions/workflows/docs.yml/badge.svg)](https://beastiary.wytamma.com/)

Beastiary is designed for visualising and analysing MCMC trace files generated from Bayesian phylogenetic analyses. Beastiary works in real-time and on remote servers (e.g. a HPC). The goal of Beastiary is to be a beautiful and simple yet powerful tool for Bayesian phylogenetic inference.

---

**Paper**: <a href="https://academic.oup.com/mbe/advance-article/doi/10.1093/molbev/msac095/6584747" target="_blank">Wirth & Duchene (2022)</a>

**Documentation**: <a href="https://beastiary.wytamma.com" target="_blank">https://beastiary.wytamma.com</a>

**Source Code**: <a href="https://github.com/Wytamma/beastiary" target="_blank">https://github.com/Wytamma/beastiary</a>

---

## Install
```bash
pip install beastiary
```

## Use
To start beastiary use the `beastiary` command.

```bash
beastiary
```

![](https://beastiary.wytamma.com/images/screen_shot_dark.png)

For more information read the [docs](https://beastiary.wytamma.com/).

# Cite

> Wytamma Wirth, Sebastian Duchene, Real-time and remote MCMC trace inspection with Beastiary, Molecular Biology and Evolution, 2022;, msac095, https://doi.org/10.1093/molbev/msac095
